@@ -1,6 +1,6 @@
 package M5;
 use base 'Exporter';
-our @EXPORT_OK = qw/m5_2/;
+our @EXPORT = qw/m5_1 m5_2/;
 
 sub m5_1{}
 sub m5_2{}
